:mod:`kwant.lattice` -- Bravais lattices
========================================

.. module:: kwant.lattice

General
-------
.. autosummary::
   :toctree: generated/

   TranslationalSymmetry
   general
   Monatomic
   Polyatomic

Library of lattices
-------------------
.. autosummary::
   :toctree: generated/

   chain
   square
   cubic
   triangular
   honeycomb
   kagome
